pytilities.overloading.overloader — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.overloading »

# pytilities.overloading.overloader

class `pytilities.overloading.overloader.` `Overloader`(overloads, add_self=True)

  A collection of Overload‘s that can process calls.

  Tool for overloading operations.

  Has an ordered collection of overloads which serve as rules, the operation of the matching overload is called. If none match, an assertion error is raised.

  `process_args`(kwargs, *args)

    Process given args and keyword args.

    Return the callable that would be called and the args it’d receive.

    Parameters: | args – arguments of the call kwargs – keyword arguments of the call
    Returns: | (processed_args, callable).
    Return type: | ({string: object}, callable)

  `process_call`(kwargs, *args)

    Process a call with given args and keyword args.

    The matching overload is called.

    Parameters: | args – arguments of the call kwargs – keyword arguments of the call
    Returns: | the return value of the called operation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.overloading »